@@ -3,7 +3,7 @@ BEGIN {
   $MooseX::MethodAttributes::AUTHORITY = 'cpan:FLORA';
 }
 BEGIN {
-  $MooseX::MethodAttributes::VERSION = '0.22';
+  $MooseX::MethodAttributes::VERSION = '0.24';
 }
 # ABSTRACT: code attribute introspection
 
@@ -31,14 +31,16 @@ sub init_meta {
     $meta = Moose::Meta::Class->initialize( $for_class )
         unless $meta;
 
-    $meta = Moose::Util::MetaRole::apply_metaclass_roles(
-        for_class                      => $for_class,
-        metaclass_roles                => ['MooseX::MethodAttributes::Role::Meta::Class'],
-        method_metaclass_roles         => ['MooseX::MethodAttributes::Role::Meta::Method'],
-        wrapped_method_metaclass_roles => ['MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped'],
+    $meta = Moose::Util::MetaRole::apply_metaroles(
+        for             => $for_class,
+        class_metaroles => {
+            class  => ['MooseX::MethodAttributes::Role::Meta::Class'],
+            method => ['MooseX::MethodAttributes::Role::Meta::Method'],
+            wrapped_method => [
+                'MooseX::MethodAttributes::Role::Meta::Method::MaybeWrapped'],
+        },
     );
 
-    $for_class = $meta->name;
     Moose::Util::MetaRole::apply_base_class_roles(
         for_class => $for_class,
         roles     => ['MooseX::MethodAttributes::Role::AttrContainer'],
@@ -52,6 +54,8 @@ sub init_meta {
 __END__
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 MooseX::MethodAttributes - code attribute introspection
@@ -76,8 +80,17 @@ meta method objects.
 
 =head1 AUTHORS
 
-  Florian Ragwitz <rafl@debian.org>
-  Tomas Doran <bobtfish@bobtfish.net>
+=over 4
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Tomas Doran <bobtfish@bobtfish.net>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
